@@ -57,12 +57,13 @@ class SequenceClassificationExplainer(BaseExplainer):
 
     def _forward(self, input_ids):
         preds = self.model(input_ids)[0]
-        self.pred_probs = torch.softmax(preds, dim=1)[0][1]
+        self.pred_probs = torch.softmax(preds, dim=1)[0][self.selected_index]
         return torch.softmax(preds, dim=1)[0][self.selected_index].unsqueeze(-1)
 
     @property
     def predicted_class_index(self):
         if self.input_ids is not None:
+            # we call this before _forward() so it has to be calculated twice
             preds = self.model(self.input_ids)[0]
             self.pred_class = torch.argmax(torch.softmax(preds, dim=0)[0])
             return torch.argmax(torch.softmax(preds, dim=1)[0]).cpu().detach().numpy()
@@ -81,7 +82,7 @@ class SequenceClassificationExplainer(BaseExplainer):
             return self.predicted_class_index
 
     def visualize(self, html_filepath: str = None, true_class: str = None):
-        tokens = self.tokenizer.convert_ids_to_tokens(self.input_ids[0])
+        tokens = [token.replace("Ġ","") for token in self.decode(self.input_ids)]
         attr_class = self.id2label[int(self.selected_index)]
         if true_class is None:
             true_class = self.predicted_class_name
@@ -100,6 +101,7 @@ class SequenceClassificationExplainer(BaseExplainer):
                 html_filepath = html_filepath + ".html"
             with open(html_filepath, "w") as html_file:
                 html_file.write(html.data)
+        return html
 
     def _calculate_attributions(self, index: int = None, class_name: str = None):
         (
@@ -120,10 +122,9 @@ class SequenceClassificationExplainer(BaseExplainer):
                 self.selected_index = self.predicted_class_index
         else:
             self.selected_index = self.predicted_class_index
-
         if self.attribution_type == "lig":
-            embeddings = getattr(self.model, self.model_type).embeddings
-            reference_tokens = self.decode(self.input_ids)
+            embeddings = self.model.get_input_embeddings()
+            reference_tokens = [token.replace("Ġ","") for token in self.decode(self.input_ids)]
             lig = LIGAttributions(
                 self._forward,
                 embeddings,
